@@ -27,10 +27,13 @@
 #  include "config.h"
 #endif
 
+#include <algorithm>
 #include <string>
 
 #include <QDir>
 #include <QFile>
+#include <QFontComboBox>
+#include <QFontDatabase>
 #include <QLibraryInfo>
 #include <QMessageBox>
 #include <QNetworkProxy>
@@ -215,15 +218,35 @@ namespace octave
 
   QString resource_manager::get_default_font_family (void)
   {
-    // Get the default monospaced font
-#if defined (HAVE_QFONT_MONOSPACE)
-    QFont fixed_font;
-    fixed_font.setStyleHint (QFont::Monospace);
-    QString default_family = fixed_font.defaultFamily ();
-#else
-    QString default_family = global_font_family;
+    QString default_family;
+
+#if defined (Q_OS_MAC)
+  // Use hard coded default on macOS, since selection of fixed width
+  // default font is unreliable (see bug #59128).
+
+  // Get all available fixed width fonts via a font combobox
+  QFontComboBox font_combo_box;
+  font_combo_box.setFontFilters (QFontComboBox::MonospacedFonts);
+  QStringList fonts;
+
+  for (int index = 0; index < font_combo_box.count(); index++)
+    fonts << font_combo_box.itemText(index);
+
+  // Test for macOS default fixed width font
+  if (fonts.contains (global_mono_font.def.toString ()))
+    default_family = global_mono_font.def.toString ();
 #endif
 
+  // If default font is still empty (on all other platforms or
+  // if macOS default font is not available): use QFontDatabase
+  if (default_family.isEmpty ())
+    {
+      // Get the system's default monospaced font
+      QFont fixed_font = QFontDatabase::systemFont (QFontDatabase::FixedFont);
+      default_family = fixed_font.defaultFamily ();
+    }
+
+    // Test env variable which has preference
     std::string env_default_family = sys::env::getenv ("OCTAVE_DEFAULT_FONT");
     if (! env_default_family.empty ())
       default_family = QString::fromStdString (env_default_family);
@@ -408,7 +431,7 @@ namespace octave
 
     // Clean up and sort list of codecs
     codecs->removeDuplicates ();
-    qSort (*codecs);
+    std::sort (codecs->begin (), codecs->end ());
   }
 
   // initialize a given combo box with available text encodings
