@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.7.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,6 +31,10 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
+
 #ifndef YY_OCTAVE_TEX_LIBINTERP_COREFCN_OCT_TEX_PARSER_H_INCLUDED
 # define YY_OCTAVE_TEX_LIBINTERP_COREFCN_OCT_TEX_PARSER_H_INCLUDED
 /* Debug traces.  */
@@ -48,36 +53,44 @@
 extern int octave_tex_debug;
 #endif
 /* "%code requires" blocks.  */
-#line 57 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1909  */
+#line 62 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
 #include <string>
 
-#line 55 "libinterp/corefcn/oct-tex-parser.h" /* yacc.c:1909  */
+#line 60 "libinterp/corefcn/oct-tex-parser.h"
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef OCTAVE_TEX_TOKENTYPE
 # define OCTAVE_TEX_TOKENTYPE
   enum octave_tex_tokentype
   {
-    BF = 258,
-    IT = 259,
-    SL = 260,
-    RM = 261,
-    FONTNAME = 262,
-    FONTSIZE = 263,
-    COLOR = 264,
-    COLOR_RGB = 265,
-    START = 266,
-    END = 267,
-    SUPER = 268,
-    SUB = 269,
-    CH = 270,
-    NUM = 271,
-    SYM = 272,
-    SCRIPT = 273,
-    STR = 274
+    OCTAVE_TEX_EMPTY = -2,
+    OCTAVE_TEX_EOF = 0,            /* "end of file"  */
+    OCTAVE_TEX_error = 256,        /* error  */
+    OCTAVE_TEX_UNDEF = 257,        /* "invalid token"  */
+    BF = 258,                      /* BF  */
+    IT = 259,                      /* IT  */
+    SL = 260,                      /* SL  */
+    RM = 261,                      /* RM  */
+    FONTNAME = 262,                /* FONTNAME  */
+    FONTSIZE = 263,                /* FONTSIZE  */
+    COLOR = 264,                   /* COLOR  */
+    COLOR_RGB = 265,               /* COLOR_RGB  */
+    START = 266,                   /* START  */
+    END = 267,                     /* END  */
+    SUPER = 268,                   /* SUPER  */
+    SUB = 269,                     /* SUB  */
+    CH = 270,                      /* CH  */
+    NUM = 271,                     /* NUM  */
+    SYM = 272,                     /* SYM  */
+    SCRIPT = 273,                  /* SCRIPT  */
+    STR = 274                      /* STR  */
   };
+  typedef enum octave_tex_tokentype octave_tex_token_kind_t;
 #endif
-/* Tokens.  */
+/* Token kinds.  */
+#define OCTAVE_TEX_EOF 0
+#define OCTAVE_TEX_error 256
+#define OCTAVE_TEX_UNDEF 257
 #define BF 258
 #define IT 259
 #define SL 260
@@ -98,26 +111,25 @@ extern int octave_tex_debug;
 
 /* Value type.  */
 #if ! defined OCTAVE_TEX_STYPE && ! defined OCTAVE_TEX_STYPE_IS_DECLARED
-
 union OCTAVE_TEX_STYPE
 {
-#line 60 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1909  */
+#line 65 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
 
   // Leaf symbols produced by the scanner.
-  char                       ch;
-  double                     num;
-  int                        sym;
+  char ch;
+  double num;
+  int sym;
 
   // Used for string buffering.
-  std::string*               str;
+  std::string *str;
 
   // Objects produced by the parser.
-  text_element*              e_base;
-  text_element_list*         e_list;
+  octave::text_element *e_base;
+  octave::text_element_list *e_list;
+
+#line 131 "libinterp/corefcn/oct-tex-parser.h"
 
-#line 119 "libinterp/corefcn/oct-tex-parser.h" /* yacc.c:1909  */
 };
-
 typedef union OCTAVE_TEX_STYPE OCTAVE_TEX_STYPE;
 # define OCTAVE_TEX_STYPE_IS_TRIVIAL 1
 # define OCTAVE_TEX_STYPE_IS_DECLARED 1
@@ -125,6 +137,6 @@ typedef union OCTAVE_TEX_STYPE OCTAVE_TEX_STYPE;
 
 
 
-int octave_tex_parse (text_parser_tex& parser);
+int octave_tex_parse (octave::text_parser_tex& parser);
 
 #endif /* !YY_OCTAVE_TEX_LIBINTERP_COREFCN_OCT_TEX_PARSER_H_INCLUDED  */
