@@ -1,6 +1,9 @@
-## Copyright (C) 2008-2018 N. J. Higham
-## Copyright (C) 2010 Richard T. Guy
-## Copyright (C) 2010 Marco Caliari
+########################################################################
+##
+## Copyright (C) 2008-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -17,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {@var{s} =} logm (@var{A})
@@ -44,7 +49,6 @@
 
 ## Author: N. J. Higham
 ## Author: Richard T. Guy <guyrt7@wfu.edu>
-## Author: Marco Caliari <marco.caliari@univr.it>
 
 function [s, iters] = logm (A, opt_iters = 100)
 
